pub struct InsertRunbooksOne;Trait Implementations
Sourceimpl GraphQLQuery for InsertRunbooksOne
impl GraphQLQuery for InsertRunbooksOne
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for InsertRunbooksOne
impl RefUnwindSafe for InsertRunbooksOne
impl Send for InsertRunbooksOne
impl Sync for InsertRunbooksOne
impl Unpin for InsertRunbooksOne
impl UnsafeUnpin for InsertRunbooksOne
impl UnwindSafe for InsertRunbooksOne